==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/DerivedBaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.DerivedAttributeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class DerivedBaseAttributeSetImpl extends InstanceSet<DerivedBaseAttributeSet,DerivedBaseAttribute> implements DerivedBaseAttributeSet {

    // attributes
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setDialect( m_Dialect );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setSuc_Pars( m_Suc_Pars );
    }


    // selections
    @Override
    public BaseAttributeSet R107_is_a_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( DerivedBaseAttribute derivedbaseattribute : this ) baseattributeset.add( derivedbaseattribute.R107_is_a_BaseAttribute() );
        return baseattributeset;
    }
    @Override
    public DerivedAttributeBodySet R693_DerivedAttributeBody() throws XtumlException {
        DerivedAttributeBodySet derivedattributebodyset = new DerivedAttributeBodySetImpl();
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedattributebodyset.add( derivedbaseattribute.R693_DerivedAttributeBody() );
        return derivedattributebodyset;
    }


    @Override
    public DerivedBaseAttribute nullElement() {
        return DerivedBaseAttributeImpl.EMPTY_DERIVEDBASEATTRIBUTE;
    }

    @Override
    public DerivedBaseAttributeSet emptySet() {
      return new DerivedBaseAttributeSetImpl();
    }

    @Override
    public DerivedBaseAttributeSet value() {
        return this;
    }

    @Override
    public List<DerivedBaseAttribute> elements() {
        return Arrays.asList(toArray(new DerivedBaseAttribute[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/DerivedBaseAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.DerivedAttributeBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.DerivedAttributeBodySetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.BaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.DerivedBaseAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.BaseAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class DerivedBaseAttributeSetImpl extends InstanceSet<DerivedBaseAttributeSet,DerivedBaseAttribute> implements DerivedBaseAttributeSet {

    public DerivedBaseAttributeSetImpl() {
    }

    public DerivedBaseAttributeSetImpl(Comparator<? super DerivedBaseAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setDialect( m_Dialect );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedbaseattribute.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public BaseAttributeSet R107_is_a_BaseAttribute() throws XtumlException {
        BaseAttributeSet baseattributeset = new BaseAttributeSetImpl();
        for ( DerivedBaseAttribute derivedbaseattribute : this ) baseattributeset.add( derivedbaseattribute.R107_is_a_BaseAttribute() );
        return baseattributeset;
    }
    @Override
    public DerivedAttributeBodySet R693_DerivedAttributeBody() throws XtumlException {
        DerivedAttributeBodySet derivedattributebodyset = new DerivedAttributeBodySetImpl();
        for ( DerivedBaseAttribute derivedbaseattribute : this ) derivedattributebodyset.add( derivedbaseattribute.R693_DerivedAttributeBody() );
        return derivedattributebodyset;
    }


    @Override
    public DerivedBaseAttribute nullElement() {
        return DerivedBaseAttributeImpl.EMPTY_DERIVEDBASEATTRIBUTE;
    }

    @Override
    public DerivedBaseAttributeSet emptySet() {
      return new DerivedBaseAttributeSetImpl();
    }

    @Override
    public DerivedBaseAttributeSet emptySet(Comparator<? super DerivedBaseAttribute> comp) {
      return new DerivedBaseAttributeSetImpl(comp);
    }

    @Override
    public DerivedBaseAttributeSet value() {
        return this;
    }

    @Override
    public List<DerivedBaseAttribute> elements() {
        return Arrays.asList(toArray(new DerivedBaseAttribute[0]));
    }

}
